util

package
v0.2.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsDev

func IsDev() bool

func Proxy

func Proxy(c1, c2 io.ReadWriteCloser)

Proxy copies data between two ReadWriteClosers in both directions. It blocks until both directions are finished or an error occurs.

func SelectMenu added in v0.2.3

func SelectMenu(prompt string, options []string) (int, error)

SelectMenu displays a selectable menu in the terminal and returns the index of the selected option. Returns -1 and an error if aborted by user (Esc or Ctrl+C).

Types

type NopWriterCloser

type NopWriterCloser struct {
	io.Writer
}

func (NopWriterCloser) Close

func (NopWriterCloser) Close() error

Jump to